unit NetScheduleJob;

interface

uses
  SysUtils, Windows, LMat;

type
  TServername = array [0..127] of WideChar;

function JobIdToStr(JobId: DWORD): String;
function JobTimeToStr(JobTime: DWORD): String;
function ExecError(Flags: UCHAR): Boolean;
function RunToday(Flags: UCHAR): Boolean;
function RunPeriodically(Flags: UCHAR): Boolean;
function DaysOfWeekToStr(DaysOfWeek: UCHAR): String;
function DaysOfMonthToStr(DaysOfMonth: DWORD): String;
function RunInteractive(Flags: UChar): Boolean;
function StringToJobTime(const Hours, Minutes: String): LongWord;

implementation

//------------------------------------------------------------------------------
function JobIdToStr(JobId: DWORD): String;
begin
  Result := IntToStr(JobId);
end;

//------------------------------------------------------------------------------
function JobTimeToStr(JobTime: DWORD): String;
var
  dwTime  : DWORD;
  strTime : String;
begin
  dwTime  := Trunc(JobTime / 1000 / 60);        // total minutes

  strTime := IntToStr(dwTime div 600);          // 10s of hours

  dwTime  := dwTime mod 600;
  strTime := strTime + IntToStr(dwTime div 60); // 1s of hours

  strTime := strTime + ':';

  dwTime  := dwTime mod 60;
  strTime := strTime + IntToStr(dwTime div 10); // 10s of minutes

  dwTime  := dwTime mod 10;
  strTime := strTime + IntToStr(dwTime);        // 1s of minutes

  Result  := strTime;
end;

//------------------------------------------------------------------------------
function StringToJobTime(const Hours, Minutes: String): LongWord;
var
  lwHours   : LongWord;
  lwMinutes : LongWord;
begin
  lwHours := StrToIntDef(Hours, 0) * 3600000;
  lwMinutes := StrToIntDef(Minutes, 0) * 60000;
  Result := lwHours + lwMinutes;
end;

//------------------------------------------------------------------------------
function ExecError(Flags: UCHAR): Boolean;
begin
  Result := (Flags and JOB_EXEC_ERROR = JOB_EXEC_ERROR);
end;

//------------------------------------------------------------------------------
function RunToday(Flags: UCHAR): Boolean;
begin
  Result := (Flags and JOB_RUNS_TODAY = JOB_RUNS_TODAY);
end;

//------------------------------------------------------------------------------
function RunPeriodically(Flags: UCHAR): Boolean;
begin
  Result := (Flags and JOB_RUN_PERIODICALLY = JOB_RUN_PERIODICALLY);
end;

//------------------------------------------------------------------------------
function DaysOfWeekToStr(DaysOfWeek: UCHAR): String;
var
  i : Integer;
begin
  Result := EmptyStr;
  if (DaysOfWeek <> 0) then
    for i := 0 to 7 do
      if (DaysOfWeek and (1 shl i) <> 0 ) then
      begin
        if (i < 6) then
          Result := Result + ShortDayNames[i + 2] + '/'
        else
          Result := Result + ShortDayNames[1] + '/';
      end;
  if (Result <> EmptyStr) then
    Delete(Result, Length(Result), 1);
end;

//------------------------------------------------------------------------------
function DaysOfMonthToStr(DaysOfMonth: DWORD): String;
var
  i : Integer;
begin
  Result := EmptyStr;
  if (DaysOfMonth <> 0) then
    for i := 0 to 31 do
      if (DaysOfMonth and (1 shl i) <> 0) then
        Result := Result + IntToStr(i + 1) + '/';
  if (Result <> EmptyStr) then
    Delete(Result, Length(Result), 1);
end;

//------------------------------------------------------------------------------
function RunInteractive(Flags: UChar): Boolean;
begin
  Result := ((Flags and JOB_NONINTERACTIVE = JOB_NONINTERACTIVE) = False);
end;


end.
