unit Main;

interface

uses
  Windows, SysUtils, Classes, Graphics, Forms, Controls, Menus,
  StdCtrls, Dialogs, Buttons, Messages, ExtCtrls, ComCtrls, StdActns,
  ActnList, ToolWin, ImgList,
  ChildWin, About, LMat;

type
  TMainForm = class(TForm)
    MainMenu: TMainMenu;
    Computer: TMenuItem;
    FileNewItem: TMenuItem;
    FileCloseItem: TMenuItem;
    Window: TMenuItem;
    Help: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    HelpAboutItem: TMenuItem;
    Edit: TMenuItem;
    WindowMinimizeItem: TMenuItem;
    StatusBar: TStatusBar;
    ActionList: TActionList;
    ComputerSelect: TAction;
    ComputerExit: TAction;
    WindowCascade: TWindowCascade;
    WindowTileHorizontal: TWindowTileHorizontal;
    WindowArrangeAll: TWindowArrange;
    WindowMinimizeAll: TWindowMinimizeAll;
    HelpAbout: TAction;
    ComputerClose: TWindowClose;
    WindowTileVertical: TWindowTileVertical;
    WindowTileItem2: TMenuItem;
    ToolBar2: TToolBar;
    ToolButton2: TToolButton;
    ToolButton3: TToolButton;
    ToolButton4: TToolButton;
    ToolButton5: TToolButton;
    ToolButton6: TToolButton;
    ToolButton9: TToolButton;
    ToolButton7: TToolButton;
    ToolButton8: TToolButton;
    ToolButton10: TToolButton;
    ToolButton11: TToolButton;
    ImageList: TImageList;
    EditAddItem: TMenuItem;
    EditChangeItem: TMenuItem;
    EditRefreshItem: TMenuItem;
    EditCopyItem: TMenuItem;
    EditPasteItem: TMenuItem;
    EditAdd: TAction;
    EditChange: TAction;
    EditRemove: TAction;
    EditRefresh: TAction;
    EditPaste: TAction;
    EditCopy: TAction;
    Remove1: TMenuItem;
    procedure ComputerSelectExecute(Sender: TObject);
    procedure HelpAboutExecute(Sender: TObject);
    procedure ComputerExitExecute(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure EditAddExecute(Sender: TObject);
    procedure EditChangeExecute(Sender: TObject);
    procedure EditRemoveExecute(Sender: TObject);
    procedure EditRefreshExecute(Sender: TObject);
    procedure EditPasteExecute(Sender: TObject);
    procedure EditCopyExecute(Sender: TObject);
    procedure FileCloseItemClick(Sender: TObject);
  private
    { Private declarations }
    FChild        : TMDIChild;
    FJobId        : LongWord;
    FpAtInfo      : PAT_INFO;
    FServername   : String;    
    procedure CreateMDIChild(const Computername: String);
    procedure SetServername(const Value: String);
  public
    { Public declarations }
  published
    property JobId : LongWord read FJobId write FJobId;
    property Servername : String read FServername write SetServername;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses
  AddChange, NetScheduleJob;

//------------------------------------------------------------------------------
procedure TMainForm.CreateMDIChild(const Computername: String);
begin
  { create a new MDI child window }
  FChild := TMDIChild.Create(Application);
  FChild.Servername := Computername;
end;

//------------------------------------------------------------------------------
procedure TMainForm.ComputerSelectExecute(Sender: TObject);
begin
  CreateMDIChild(Servername);
end;

//------------------------------------------------------------------------------      
procedure TMainForm.HelpAboutExecute(Sender: TObject);
begin
  AboutBox := TAboutBox.Create(Application);
  with AboutBox do
  begin
    try
      ProgramIcon.Picture.Icon.Assign(Application.Icon);
      ProductName.Caption := Application.Title;
      Version.Caption := '1.0';
      Copyright.Caption := '1999 Christian Storb';
      Comments.Caption := 'Program to control the task schedule service (at).';
      ShowModal;
    finally
      Free;
    end;
  end;
end;

//------------------------------------------------------------------------------
procedure TMainForm.ComputerExitExecute(Sender: TObject);
begin
  Close;
end;

//------------------------------------------------------------------------------
procedure TMainForm.FormCreate(Sender: TObject);
var
  lpBuffer : PChar;
  nSize    : Cardinal;
begin
  nSize := 255;
  GetMem(lpBuffer, nSize);
  if GetComputername(lpBuffer, nSize) then
    Servername := String(lpBuffer);
  FreeMem(lpBuffer);
end;

//------------------------------------------------------------------------------
procedure TMainForm.SetServername(const Value: String);
begin
  if (Value <> FServername) then
  begin
    FServername := Value;
    Caption := Caption + ' - \\' + FServername;
  end;
end;

//------------------------------------------------------------------------------
procedure TMainForm.FormShow(Sender: TObject);
begin
  CreateMDIChild(Servername);
  ToolButton11.Click;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditAddExecute(Sender: TObject);
begin
  AddChangeForm := TAddChangeForm.Create(Application);
  with AddChangeForm do
  begin
    try
      Caption := 'Add a job on \\' + FServername;
      JobId := FJobId;
      Servername := FServername;

      if (AddChangeForm.ShowModal = mrOk) then
        FChild.RefreshLvJobEnum;
    finally
      AddChangeForm.Free;
    end;
  end;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditChangeExecute(Sender: TObject);
begin
  if not FChild.JobExists(JobId) then
  begin
    MessageDlg('Please select a job!', mtInformation, [mbOK], 0);
    exit;
  end;

  AddChangeForm := TAddChangeForm.Create(Application);
  with AddChangeForm do
  begin
    try
      Caption := 'Change job ' + IntToStr(FJobId) + ' on \\' + FServername;
      JobId := FJobId;
      Servername := FServername;
      JobShow;
      if (AddChangeForm.ShowModal = mrOk) then
        FChild.RefreshLvJobEnum;
    finally
      AddChangeForm.Free;
    end;
  end;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditRemoveExecute(Sender: TObject);
var
  Dest : TServername;
begin
  if not FChild.JobExists(JobId) then
  begin
    MessageDlg('Please select a job!', mtInformation, [mbOK], 0);
    exit;
  end
  else if MessageDlg('Do you want to remove job ' + IntToStr(JobId) + '?',
    mtConfirmation, [mbYes, mbNo], 0) = mrNo then
      exit;

  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
  NetScheduleJobDel(Dest, JobId, JobId);
  
  FChild.RefreshLvJobEnum;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditRefreshExecute(Sender: TObject);
begin
  FChild.RefreshLvJobEnum;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditPasteExecute(Sender: TObject);
var
  AtInfo : AT_INFO;
  Dest   : TServername;
begin
  if (FpAtInfo = nil) then
  begin
    MessageDlg('No data!', mtInformation, [mbOK], 0);
    exit;
  end;

  with AtInfo do
  begin
    JobTime     := FpAtInfo^.JobTime;
    DaysOfMonth := FpAtInfo^.DaysOfMonth;
    DaysOfWeek  := FpAtInfo^.DaysOfWeek;
    Flags       := FpAtInfo^.Flags;
    Command     := FpAtInfo^.Command;
  end;

  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
  NetScheduleJobAdd(Dest, PByte(@AtInfo), @FJobId);

  FpAtInfo := nil;

  FChild.RefreshLvJobEnum;
end;

//------------------------------------------------------------------------------
procedure TMainForm.EditCopyExecute(Sender: TObject);
var
  Dest : TServername;
begin
  StringToWideChar(Servername, @Dest, SizeOf(Dest) div 2);
  NetScheduleJobGetInfo(Dest, FChild.JobId, PByte(@FpAtInfo));
end;

//------------------------------------------------------------------------------
procedure TMainForm.FileCloseItemClick(Sender: TObject);
begin
  //
end;

end.
